Learn R Programming

LICurvature (version 0.1.1)

LICurvature-package: Assement on Local Influence in Case-Weight for the Linear Regression Models

Description

This Package presents a general method for assessing the local influence of minor perturbations of case-weight for the linear regression models. The method relies on a well-behaved likelihood and certain elementary ideas from differential geometry, and seems to provide a relatively simple, unified approach for handling a variety of problems. A distinguishing feature of this method is its use of log-likelihood contours to gauge influence. Although this Package is concerned primarily with local influence, some discussion of assessing global influence, which is a significantly more difficult problem. We use geometric normal curvatures to characterize the behaviour of an influence graph around omega (Generally, omega can reflect any well-defined perturbation scheme and thus is not restricted to be a collection of case weights.),although the essential results can be obtained by using less descriptive We used it in case-Weight for the linear regression models, also recommended a general reference for deciding whether there is notable local sensitivity or not

Arguments

Details

Package:
LICurvature
Type:
Package
Version:
1.0
Date:
2013-06-23
License:
GPL (>=2)

References

Cook, R. D. (1986). Assessment of local influence (with discussion). J. Roy. Statist. Soc. Ser. B 48: 133-169.

Examples

Run this code
data("Bahrami1")
gender<-Bahrami1$ GENDER
duration <-Bahrami1$ DURATION
y<-Bahrami1$  BMI
X=cbind(gender,duration )
Xstar=cbind(1,X)
p=2;
n=15;
ini=c(0,rep(1,p));

LICurvature(ini,X=X,Xstar=Xstar,y=y,n=n,p=p)

Run the code above in your browser using DataLab